==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d6/db0/win32_8cpp.js <==
var win32_8cpp =
[
    [ "DIR", "dd/dfe/structDIR.html", "dd/dfe/structDIR" ],
    [ "LINGUISTIC_IGNORECASE", "d6/db0/win32_8cpp.html#a34fa34780c148366b420e0cc81c7207a", null ],
    [ "NO_SHOBJIDL_SORTDIRECTION", "d6/db0/win32_8cpp.html#a77f39e14f6cd224399b60eb2e1ec3d5c", null ],
    [ "SORT_DIGITSASNUMBERS", "d6/db0/win32_8cpp.html#ac4593826aef91d99e71ac4972b07f40b", null ],
    [ "W", "d6/db0/win32_8cpp.html#ae61022973d1dd4010d2346f71d2d2ded", null ],
    [ "closedir", "d6/db0/win32_8cpp.html#a058e669d865116ec6419ea3a52207830", null ],
    [ "convert_from_fs", "d6/db0/win32_8cpp.html#a5d18c43897b21068cbb08570535d1b61", null ],
    [ "convert_to_fs", "d6/db0/win32_8cpp.html#a20a236b9c42718f9f44ca3492daa0cde", null ],
    [ "CreateConsole", "d6/db0/win32_8cpp.html#a9c93eb8d3d9e95f670a42345713af01a", null ],
    [ "CSleep", "d6/db0/win32_8cpp.html#a04192f4474b4eb1abf1a7a2e96167209", null ],
    [ "DetermineBasePaths", "d6/db0/win32_8cpp.html#ad76ea608973c015f4596d915a7e1aaa0", null ],
    [ "dir_calloc", "d6/db0/win32_8cpp.html#a296d029faeb5d8ecbbd8cd11955bd475", null ],
    [ "dir_free", "d6/db0/win32_8cpp.html#a856c9e0981f787f031ec8a3abd9d1be0", null ],
    [ "FiosGetDiskFreeSpace", "d6/db0/win32_8cpp.html#ac129bca32e29df8cf112f80069bd9d35", null ],
    [ "FiosGetDrives", "d6/db0/win32_8cpp.html#a4e5a663c2a59e11991acc39af6bc9c80", null ],
    [ "FiosIsHiddenFile", "d6/db0/win32_8cpp.html#a3d56504739cfb55a2f744cf8369c9400", null ],
    [ "FiosIsRoot", "d6/db0/win32_8cpp.html#a7dd3ce143ab6591de9a6db6f37598c90", null ],
    [ "FiosIsValidFile", "d6/db0/win32_8cpp.html#af4f7cf91e607f979aad28a05212d32d7", null ],
    [ "FS2OTTD", "d6/db0/win32_8cpp.html#ab2516383bc393c611e0ff5ccf72a458c", null ],
    [ "GetClipboardContents", "d6/db0/win32_8cpp.html#a1634022c455b3d02e75598ccc63bee94", null ],
    [ "GetCPUCoreCount", "d6/db0/win32_8cpp.html#a9d57d2889af467131baf27be824838a3", null ],
    [ "GetCurrentLocale", "d6/db0/win32_8cpp.html#a59f41332962217dd03e506a019e50a10", null ],
    [ "getcwd", "d6/db0/win32_8cpp.html#a3284211bd28346254245c9d4fd071d7f", null ],
    [ "HelpDialogFunc", "d6/db0/win32_8cpp.html#a7428df991ac132ad63f11ff60a3079d1", null ],
    [ "LoadLibraryList", "d6/db0/win32_8cpp.html#ab5366d09f96bd1ee3e3ae0d3c3f29817", null ],
    [ "MyShowCursor", "d6/db0/win32_8cpp.html#afcb16bb089908c36a022e1beb6750ae5", null ],
    [ "opendir", "d6/db0/win32_8cpp.html#adbb38eee0be7cfe687b70284cb6ce5b7", null ],
    [ "OSOpenBrowser", "d6/db0/win32_8cpp.html#a3947ae7fb7dfd95675183b12a61d07aa", null ],
    [ "OTTD2FS", "d6/db0/win32_8cpp.html#a986b7eaab2ae6b172bf04a0948f7ca42", null ],
    [ "OTTDSHGetFolderPath", "d6/db0/win32_8cpp.html#a96609af80e76b36c0be333c364258476", null ],
    [ "OTTDStringCompare", "d6/db0/win32_8cpp.html#af6fc0165498bc9a2f74b1521a1fcbd77", null ],
    [ "ParseCommandLine", "d6/db0/win32_8cpp.html#a1abc00172a314adb60eac35348f486c2", null ],
    [ "readdir", "d6/db0/win32_8cpp.html#aa7687571d2af8efd5153874ae6e678d9", null ],
    [ "ShowInfo", "d6/db0/win32_8cpp.html#a18cb8ca0682f09d125b9e4b8df1fddc9", null ],
    [ "ShowOSErrorBox", "d6/db0/win32_8cpp.html#a200036bd3624f24bbbd5c8f0009d3366", null ],
    [ "Win32SetCurrentLocaleName", "d6/db0/win32_8cpp.html#a7861e4d5ac2898047c9a6f980003b547", null ],
    [ "WinMain", "d6/db0/win32_8cpp.html#a1122673f59be78a3997ec7dd1c4688f9", null ],
    [ "_cur_iso_locale", "d6/db0/win32_8cpp.html#aee91e98fe841a0ff59ec83b36dd07ff4", null ],
    [ "_cursor_disable", "d6/db0/win32_8cpp.html#ac90854222e54c0959dd1187ca2fdfc95", null ],
    [ "_cursor_visible", "d6/db0/win32_8cpp.html#a59754e8faabf00cc315608cbe78c60a2", null ],
    [ "_global_dir", "d6/db0/win32_8cpp.html#afdd5ff100e8fec7f1b195555f3ad8748", null ],
    [ "_global_dir_is_in_use", "d6/db0/win32_8cpp.html#ade3bc16e8de786096eaca53756061f96", null ],
    [ "_has_console", "d6/db0/win32_8cpp.html#a7cb31014400ffb0a69a7327cd934d364", null ],
    [ "_help_msg", "d6/db0/win32_8cpp.html#a139402d40c032d6b62ef50b081f425af", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d6/db0/win32_8cpp.js <==
var win32_8cpp =
[
    [ "DIR", "dd/dfe/structDIR.html", "dd/dfe/structDIR" ],
    [ "LINGUISTIC_IGNORECASE", "d6/db0/win32_8cpp.html#a34fa34780c148366b420e0cc81c7207a", null ],
    [ "NO_SHOBJIDL_SORTDIRECTION", "d6/db0/win32_8cpp.html#a77f39e14f6cd224399b60eb2e1ec3d5c", null ],
    [ "SORT_DIGITSASNUMBERS", "d6/db0/win32_8cpp.html#ac4593826aef91d99e71ac4972b07f40b", null ],
    [ "W", "d6/db0/win32_8cpp.html#ae61022973d1dd4010d2346f71d2d2ded", null ],
    [ "closedir", "d6/db0/win32_8cpp.html#a058e669d865116ec6419ea3a52207830", null ],
    [ "convert_from_fs", "d6/db0/win32_8cpp.html#a5d18c43897b21068cbb08570535d1b61", null ],
    [ "convert_to_fs", "d6/db0/win32_8cpp.html#a20a236b9c42718f9f44ca3492daa0cde", null ],
    [ "CreateConsole", "d6/db0/win32_8cpp.html#a9c93eb8d3d9e95f670a42345713af01a", null ],
    [ "DetermineBasePaths", "d6/db0/win32_8cpp.html#ad76ea608973c015f4596d915a7e1aaa0", null ],
    [ "dir_calloc", "d6/db0/win32_8cpp.html#a296d029faeb5d8ecbbd8cd11955bd475", null ],
    [ "dir_free", "d6/db0/win32_8cpp.html#a856c9e0981f787f031ec8a3abd9d1be0", null ],
    [ "FiosGetDiskFreeSpace", "d6/db0/win32_8cpp.html#ac129bca32e29df8cf112f80069bd9d35", null ],
    [ "FiosGetDrives", "d6/db0/win32_8cpp.html#a4e5a663c2a59e11991acc39af6bc9c80", null ],
    [ "FiosIsHiddenFile", "d6/db0/win32_8cpp.html#a3d56504739cfb55a2f744cf8369c9400", null ],
    [ "FiosIsRoot", "d6/db0/win32_8cpp.html#a7dd3ce143ab6591de9a6db6f37598c90", null ],
    [ "FiosIsValidFile", "d6/db0/win32_8cpp.html#af4f7cf91e607f979aad28a05212d32d7", null ],
    [ "FS2OTTD", "d6/db0/win32_8cpp.html#ab2516383bc393c611e0ff5ccf72a458c", null ],
    [ "GetClipboardContents", "d6/db0/win32_8cpp.html#a1634022c455b3d02e75598ccc63bee94", null ],
    [ "GetCurrentLocale", "d6/db0/win32_8cpp.html#a59f41332962217dd03e506a019e50a10", null ],
    [ "getcwd", "d6/db0/win32_8cpp.html#a3284211bd28346254245c9d4fd071d7f", null ],
    [ "HelpDialogFunc", "d6/db0/win32_8cpp.html#a7428df991ac132ad63f11ff60a3079d1", null ],
    [ "LoadLibraryList", "d6/db0/win32_8cpp.html#ab5366d09f96bd1ee3e3ae0d3c3f29817", null ],
    [ "MyShowCursor", "d6/db0/win32_8cpp.html#afcb16bb089908c36a022e1beb6750ae5", null ],
    [ "opendir", "d6/db0/win32_8cpp.html#adbb38eee0be7cfe687b70284cb6ce5b7", null ],
    [ "OSOpenBrowser", "d6/db0/win32_8cpp.html#a3947ae7fb7dfd95675183b12a61d07aa", null ],
    [ "OTTD2FS", "d6/db0/win32_8cpp.html#a986b7eaab2ae6b172bf04a0948f7ca42", null ],
    [ "OTTDSHGetFolderPath", "d6/db0/win32_8cpp.html#a96609af80e76b36c0be333c364258476", null ],
    [ "OTTDStringCompare", "d6/db0/win32_8cpp.html#af6fc0165498bc9a2f74b1521a1fcbd77", null ],
    [ "ParseCommandLine", "d6/db0/win32_8cpp.html#a1abc00172a314adb60eac35348f486c2", null ],
    [ "readdir", "d6/db0/win32_8cpp.html#aa7687571d2af8efd5153874ae6e678d9", null ],
    [ "SetCurrentThreadName", "d6/db0/win32_8cpp.html#a8ad0c6d2e3dd097f0638363c2cf955f2", null ],
    [ "ShowInfo", "d6/db0/win32_8cpp.html#a18cb8ca0682f09d125b9e4b8df1fddc9", null ],
    [ "ShowOSErrorBox", "d6/db0/win32_8cpp.html#a200036bd3624f24bbbd5c8f0009d3366", null ],
    [ "Win32SetCurrentLocaleName", "d6/db0/win32_8cpp.html#a7861e4d5ac2898047c9a6f980003b547", null ],
    [ "WinMain", "d6/db0/win32_8cpp.html#a1122673f59be78a3997ec7dd1c4688f9", null ],
    [ "_config_file", "d6/db0/win32_8cpp.html#ad24b90719b1d40843c682f9b7a778f97", null ],
    [ "_cur_iso_locale", "d6/db0/win32_8cpp.html#aee91e98fe841a0ff59ec83b36dd07ff4", null ],
    [ "_cursor_disable", "d6/db0/win32_8cpp.html#ac90854222e54c0959dd1187ca2fdfc95", null ],
    [ "_cursor_visible", "d6/db0/win32_8cpp.html#a59754e8faabf00cc315608cbe78c60a2", null ],
    [ "_global_dir", "d6/db0/win32_8cpp.html#afdd5ff100e8fec7f1b195555f3ad8748", null ],
    [ "_global_dir_is_in_use", "d6/db0/win32_8cpp.html#ade3bc16e8de786096eaca53756061f96", null ],
    [ "_has_console", "d6/db0/win32_8cpp.html#a7cb31014400ffb0a69a7327cd934d364", null ],
    [ "_help_msg", "d6/db0/win32_8cpp.html#a139402d40c032d6b62ef50b081f425af", null ]
];
